class JobInputList extends RessourceList {
  static autoInit() {
    for (let jobInputListElement of document.querySelectorAll('.job-input-list:not(.no-autoinit)')) {
      new JobInputList(jobInputListElement);
    }
  }

  static options = {
    initialHtmlGenerator: (id) => {
      return `
        <div class="input-field">
          <i class="material-icons prefix">search</i>
          <input id="${id}-search" class="search" type="search"></input>
          <label for="${id}-search">Search job input</label>
        </div>
        <table>
          <thead>
            <tr>
              <th>Filename</th>
              <th></th>
            </tr>
          </thead>
          <tbody class="list"></tbody>
        </table>
        <ul class="pagination"></ul>
      `.trim();
    },
    item: `
      <tr class="clickable hoverable">
        <td><span class="filename"></span></td>
        <td class="right-align">
          <a class="action-button btn-floating waves-effect waves-light" data-action="download"><i class="material-icons">file_download</i></a>
        </td>
      </tr>
    `.trim(),
    ressourceMapper: (jobInput) => {
      return {
        'id': jobInput.id,
        'creation-date': jobInput.creation_date,
        'filename': jobInput.filename
      };
    },
    sortArgs: ['filename', {order: 'asc'}],
    valueNames: [
      {data: ['id']},
      {data: ['creation-date']},
      'filename'
    ]
  };

  constructor(listElement, options = {}) {
    super(listElement, {...JobInputList.options, ...options});
    this.jobId = listElement.dataset.jobId;
  }

  init(user) {
    this._init(user.jobs[this.jobId].inputs);
  }

  onClick(event) {
    let actionButtonElement = event.target.closest('.action-button');
    let action = actionButtonElement === null ? 'download' : actionButtonElement.dataset.action;
    let jobInputElement = event.target.closest('tr');
    let jobInputId = jobInputElement.dataset.id;
    switch (action) {
      case 'download': {
        window.location.href = `/jobs/${this.jobId}/inputs/${jobInputId}/download`;
        break;
      }
      default: {
        break;
      }
    }
  }

  onPatch(patch) {return;}
}
